Assign sequences to cluster models that give the highest sequence-to-hmm
likelihood. Used in hmm.clust.
assign.clusters(partition, memberships, sequences, smoothing = 1e-04)The updated matrix with cluster memberships for each sequence.
A list object with the partition, a mixture of HMMs. Each
element in the list is an hmm object (see
build_hmm).
A matrix with cluster memberships for each sequence.
An stslist object (see
seqdef) of sequences with discrete observations.
Smoothing parameter for absolute discounting in
smooth.probabilities.
Used in main function for the DBHC algorithm
hmm.clust.