Learn R Programming

DBHC (version 0.0.3)

model.ll: Get HMM Log Likelihood

Description

Get the log likelihood of an HMM object and check if it is feasible (i.e., contains no illegal emissions). Auxiliary function used in partition.bic.

Usage

model.ll(hmm)

Value

The log likelihood of the hmm object, print warning if model is infeasible (i.e., if the log likelihood is evaluated for a sequence that contains emissions that are assigned probability 0 in the hmm

object).

Arguments

hmm

An hmm object (see build_hmm).

See Also

Used in partition.bic.