Learn R Programming

DBHC (version 0.0.3)

select.seeds: Seed Selection Procedure

Description

Seed selection procedure of the DBHC algorithm, also invokes size search algorithm for seed in size.search. Used in hmm.clust.

Usage

select.seeds(
  sequences,
  log_space = FALSE,
  K,
  seed.size = 3,
  init.size = 2,
  print = FALSE,
  smoothing = 1e-04
)

Value

A partition as a list object with HMMs for the selected seeds.

Arguments

sequences

An stslist object (see seqdef) of sequences with discrete observations.

log_space

Logical, parameter provided to fit_model for whether to use optimization in log space or not.

K

The number of seeds to select, equal to the number of clusters in a partition.

seed.size

Seed size, the number of sequences to be selected for a seed.

init.size

The number of HMM states in an initial HMM.

print

Logical, whether to print intermediate steps or not.

smoothing

Smoothing parameter for absolute discounting in smooth.probabilities.

See Also

Used in main function for the DBHC algorithm hmm.clust.