Compute the sequence-to-HMM likelihood of an HMM evaluated for a single
sequence and check if the sequence contains emissions that are not possible
according to the HMM. Auxiliary function used in select.seeds
and assign.clusters.
seq2hmm.ll(hmm)The log likelihood of the sequence contained in hmm, value
will be set to minus infinity if the sequence contains illegal emissions.
An hmm object (see build_hmm)
containing a single sequence.
Used in select.seeds and
assign.clusters.