The size search algorithm finds the optimal number of HMM states for a set of
sequences and returns both the optimal hmm object and the
corresponding number of hidden states. Used in select.seeds.
size.search(sequences, log_space = FALSE, print = FALSE)A list with the optimal number of HMM states and the optimal
hmm object.
An stslist object (see
seqdef) of sequences with discrete observations.
Logical, parameter provided to
fit_model for whether to use optimization in log
space or not.
Logical, whether to print intermediate steps or not.
Used in the DBHC seed selection procedure in
select.seeds.