Get the log likelihood of an HMM object and check if it is feasible (i.e.,
contains no illegal emissions). Auxiliary function used in
partition.bic.
Usage
model.ll(hmm)
Value
The log likelihood of the hmm object, print warning if model
is infeasible (i.e., if the log likelihood is evaluated for a sequence that
contains emissions that are assigned probability 0 in the hmm