Seed selection procedure of the DBHC algorithm, also invokes size search
algorithm for seed in size.search. Used in hmm.clust.
select.seeds(
sequences,
log_space = FALSE,
K,
seed.size = 3,
init.size = 2,
print = FALSE,
smoothing = 1e-04
)A partition as a list object with HMMs for the selected seeds.
An stslist object (see
seqdef) of sequences with discrete observations.
Logical, parameter provided to
fit_model for whether to use optimization in log
space or not.
The number of seeds to select, equal to the number of clusters in a partition.
Seed size, the number of sequences to be selected for a seed.
The number of HMM states in an initial HMM.
Logical, whether to print intermediate steps or not.
Smoothing parameter for absolute discounting in
smooth.probabilities.
Used in main function for the DBHC algorithm
hmm.clust.